From 2ad62560658560530f6c3a42a88fa3197edec6f2 Mon Sep 17 00:00:00 2001
From: "Jonathan S. Katz" <jonathan.katz@excoventures.com>
Date: Sun, 21 Mar 2021 15:04:26 -0400
Subject: [PATCH 2/3] Refactor generation of CVE number from CVE ID

This allows the method to be repurposed in additional parts of
the pgweb codebase.
---
 pgweb/security/models.py | 20 +++++++++++++++++---
 1 file changed, 17 insertions(+), 3 deletions(-)

diff --git a/pgweb/security/models.py b/pgweb/security/models.py
index 6f38764..8ee6e55 100644
--- a/pgweb/security/models.py
+++ b/pgweb/security/models.py
@@ -28,6 +28,18 @@ def cve_validator(val):
         raise ValidationError("Enter CVE in format 0000-0000 without the CVE text")
 
 
+def make_cvenumber(cve):
+    """
+    creates a ``cvenumber`` from a CVE ID string (e.g. YYYY-DDDDD).
+
+    raises a validation error if the CVE ID string is invalid
+    """
+    m = re_cve.match(cve)
+    if not m:
+        raise ValidationError("Invalid CVE")
+    return 100000 * int(m.groups(0)[0]) + int(m.groups(0)[1])
+
+
 def other_vectors_validator(val):
     if val != val.upper():
         raise ValidationError("Vector must be uppercase")
@@ -80,10 +92,12 @@ class SecurityPatch(models.Model):
         if self.cve == '':
             self.cvenumber = 0
         else:
-            m = re_cve.match(self.cve)
-            if not m:
+            try:
+                self.cvenumber = make_cvenumber(self.cve)
+            except ValidationError:
+                # catch and re-raise the error, to be consistent with previous
+                # logging that states we should not get here, i.e.:
                 raise ValidationError("Invalid CVE, should not get here!")
-            self.cvenumber = 100000 * int(m.groups(0)[0]) + int(m.groups(0)[1])
         super(SecurityPatch, self).save(force_insert, force_update)
 
     def __str__(self):
-- 
2.21.1 (Apple Git-122.3)

